@@ -13,6 +13,7 @@
 #include <PowerDevilProfileSettings.h>
 #include <powerdevil_debug.h>
 #include <powerdevilcore.h>
+#include <powerdevilenums.h>
 
 #include <QAction>
 #include <QDebug>
@@ -35,10 +36,10 @@ KeyboardBrightnessControl::KeyboardBrightnessControl(QObject *parent)
     // DBus
     new KeyboardBrightnessControlAdaptor(this);
 
-    connect(core()->backend(),
-            &PowerDevil::BackendInterface::keyboardBrightnessChanged,
+    connect(core()->keyboardBrightnessController(),
+            &KeyboardBrightnessController::brightnessInfoChanged,
             this,
-            &PowerDevil::BundledActions::KeyboardBrightnessControl::onBrightnessChangedFromBackend);
+            &PowerDevil::BundledActions::KeyboardBrightnessControl::onBrightnessChangedFromController);
 
     KActionCollection *actionCollection = new KActionCollection(this);
     actionCollection->setComponentDisplayName(i18nc("Name for powerdevil shortcuts category", "Power Management"));
@@ -80,7 +81,7 @@ void KeyboardBrightnessControl::onProfileLoad(const QString &previousProfile, co
         // We don't want to change anything here
         qCDebug(POWERDEVIL) << "Not changing keyboard brightness, the current one is lower and the profile is more conservative";
     } else {
-        backend()->setKeyboardBrightness(absoluteKeyboardBrightnessValue);
+        core()->keyboardBrightnessController()->setBrightness(absoluteKeyboardBrightnessValue);
     }
 }
 
@@ -90,7 +91,7 @@ void KeyboardBrightnessControl::triggerImpl(const QVariantMap & /*args*/)
 
 bool KeyboardBrightnessControl::isSupported()
 {
-    return backend()->keyboardBrightnessAvailable();
+    return core()->keyboardBrightnessController()->isSupported();
 }
 
 bool KeyboardBrightnessControl::loadAction(const PowerDevil::ProfileSettings &profileSettings)
@@ -103,7 +104,7 @@ bool KeyboardBrightnessControl::loadAction(const PowerDevil::ProfileSettings &pr
     return true;
 }
 
-void KeyboardBrightnessControl::onBrightnessChangedFromBackend(const BrightnessLogic::BrightnessInfo &info)
+void KeyboardBrightnessControl::onBrightnessChangedFromController(const KeyboardBrightnessLogic::BrightnessInfo &info)
 {
     m_lastKeyboardBrightness = info.value;
     Q_EMIT keyboardBrightnessChanged(info.value);
@@ -112,46 +113,46 @@ void KeyboardBrightnessControl::onBrightnessChangedFromBackend(const BrightnessL
 
 void KeyboardBrightnessControl::increaseKeyboardBrightness()
 {
-    backend()->keyboardBrightnessKeyPressed(BrightnessLogic::Increase);
-    BrightnessOSDWidget::show(keyboardBrightnessPercent(), BackendInterface::Keyboard);
+    core()->keyboardBrightnessController()->keyboardBrightnessKeyPressed(BrightnessLogic::Increase);
+    BrightnessOSDWidget::show(keyboardBrightnessPercent(), PowerDevil::BrightnessControlType::Keyboard);
 }
 
 void KeyboardBrightnessControl::decreaseKeyboardBrightness()
 {
-    backend()->keyboardBrightnessKeyPressed(BrightnessLogic::Decrease);
-    BrightnessOSDWidget::show(keyboardBrightnessPercent(), BackendInterface::Keyboard);
+    core()->keyboardBrightnessController()->keyboardBrightnessKeyPressed(BrightnessLogic::Decrease);
+    BrightnessOSDWidget::show(keyboardBrightnessPercent(), PowerDevil::BrightnessControlType::Keyboard);
 }
 
 void KeyboardBrightnessControl::toggleKeyboardBacklight()
 {
-    backend()->keyboardBrightnessKeyPressed(BrightnessLogic::Toggle);
-    BrightnessOSDWidget::show(keyboardBrightnessPercent(), BackendInterface::Keyboard);
+    core()->keyboardBrightnessController()->keyboardBrightnessKeyPressed(BrightnessLogic::Toggle);
+    BrightnessOSDWidget::show(keyboardBrightnessPercent(), PowerDevil::BrightnessControlType::Keyboard);
 }
 
 int KeyboardBrightnessControl::keyboardBrightness() const
 {
-    return backend()->keyboardBrightness();
+    return core()->keyboardBrightnessController()->brightness();
 }
 
 int KeyboardBrightnessControl::keyboardBrightnessMax() const
 {
-    return backend()->keyboardBrightnessMax();
+    return core()->keyboardBrightnessController()->maxBrightness();
 }
 
 void KeyboardBrightnessControl::setKeyboardBrightness(int percent)
 {
-    backend()->setKeyboardBrightness(percent);
-    BrightnessOSDWidget::show(keyboardBrightnessPercent(), BackendInterface::Keyboard);
+    core()->keyboardBrightnessController()->setBrightness(percent);
+    BrightnessOSDWidget::show(keyboardBrightnessPercent(), PowerDevil::BrightnessControlType::Keyboard);
 }
 
 void KeyboardBrightnessControl::setKeyboardBrightnessSilent(int percent)
 {
-    backend()->setKeyboardBrightness(percent);
+    core()->keyboardBrightnessController()->setBrightness(percent);
 }
 
 int KeyboardBrightnessControl::keyboardBrightnessSteps() const
 {
-    return backend()->keyboardBrightnessSteps();
+    return core()->keyboardBrightnessController()->brightnessSteps();
 }
 
 int KeyboardBrightnessControl::keyboardBrightnessPercent() const
